API
===

Each page in this section contains documentation on a module in Eww.  The documentation is autogenerated from the source code.

As described on the :ref:`versioning` page, only a small number of methods are intended to be used by end users.  The interfaces described there as public are the only interfaces where compatibility is guaranteed.

This documentation is geared towards developers looking to contribute to Eww.  Anything not positively identified as public should not be used by anyone implementing Eww.

.. toctree::
   :maxdepth: 2
   :hidden:

   command
   console
   dispatch
   implant
   ioproxy
   parser
   quitterproxy
   shared
   stats
   stoppable_thread
   client